import request from '@/utils/request'

// 查询财务月度汇总列表
export function listMonthSummary(query) {
  return request({
    url: '/system/monthSummary/list',
    method: 'get',
    params: query
  })
}

// 查询财务月度汇总详细
export function getMonthSummary(summaryId) {
  return request({
    url: '/system/monthSummary/' + summaryId,
    method: 'get'
  })
}

// 新增财务月度汇总
export function addMonthSummary(data) {
  return request({
    url: '/system/monthSummary',
    method: 'post',
    data: data
  })
}

// 修改财务月度汇总
export function updateMonthSummary(data) {
  return request({
    url: '/system/monthSummary',
    method: 'put',
    data: data
  })
}

// 删除财务月度汇总
export function delMonthSummary(summaryId) {
  return request({
    url: '/system/monthSummary/' + summaryId,
    method: 'delete'
  })
}
// 查询财务月度汇总详细
export function costDetailsList(query) {
  return request({
    url: '/system/costDetails/list',
    method: 'get',
    params: query
  })
}
//
export function getAccountAdjustment(query) {
  return request({
    url: '/system/costDetails/getAccountAdjustment',
    method: 'get',
    params: query
  })
}
export function putAccountAdjustment(query) {
  return request({
    url: '/system/costDetails/accountAdjustment',
    method: 'put',
    data: query
  })
}
// 开具发票
export function invoiceIssuance(query) {
  return request({
    url: '/system/invoice/invoiceIssuance',
    method: 'post',
    data: query
  })
}

// 票据回传
export function invoiceReturnShop(query) {
  return request({
    url: '/system/invoice/returnShop',
    method: 'post',
    data: query
  })
}